/**
 * Example implementation for purchasing subscriptions.
 * To keep the code simple, we are hardcoding subscription
 * identifiers into the BannerDemo.subscribe() calls. These
 * should be fetched using the Banner.getSubscriptions() API
 * method, rather than using hardcoded values in a live
 * implementation.
*/
(function( global ) {
	// Get handles
	var loginButton = document.getElementById( 'loginButton' ),
		logoutButton = document.getElementById( 'logoutButton' ),
		threeMonthButton = document.getElementById( 'threeMonthsButton' );
        sixMonthButton = document.getElementById( 'sixMonthsButton' );
        twelveMonthButton = document.getElementById( 'twelveMonthsButton' );

	// As its a demo, we'll do this
	var subs = [];

	var onLogin = function( res ) {
		console.log( 'Login Callback Fired' );
	};

	var onSubscribe = function( identifier, status, expiry ) {
        console.log( 'Subscribe Callback Fired' );
        var selector = selectorForIdentifier( identifier );
		document.querySelector( selector + " span" ).className = '';
        if (status == Banner.SubscriptionStatus.SUCCESS) {
            document.querySelector( selector + " span" ).innerHTML = "PURCHASED";
        }
		document.querySelector( selector + ' .subscribingIcon' ).className = 'subscribingIcon hidden';
	};

	var onGetSubscriptions = function( res ) {
		if ( res.length ) {
            res.forEach(function(entry) {
                if (entry.subscribed == 1) {
            		document.querySelector( selector + " span" ).className = '';
                    document.querySelector( selector + " span" ).innerHTML = "PURCHASED";
            		document.querySelector( selector + ' .subscribingIcon' ).className = 'subscribingIcon hidden';
                } else {
                    var selector = selectorForIdentifier( entry.identifier );
                    if (selector != null) {
                        price = entry.price == null ? "FREE" : '£' + entry.price;
    			        document.querySelector( selector + " span" ).innerHTML = price;
                    }
                }
            });
		}

		// Flat replace global subs
		subs = res;
	};
    
    var selectorForIdentifier = function ( identifier ) {
        var selector = null;
        if (identifier == "com.pub1.3month") {
            selector = "#threeMonthsButton";
        }
        else if ( identifier == "autorenew.sub1.1" ) {
            selector = "#sixMonthsButton";
        }
        else if ( identifier == "autorenew.sub4" ) {
            selector = "#twelveMonthsButton";
        }
        return selector;
    }

	var onLoginChange = function( res ) {
		console.log( 'login change' );
		console.log( res.userName ? 'logged in as ' + res.userName : 'currently logged out' );

		function updateUsername( username ) {
			elUserName.innerHTML = username;
		}

		function showLogin() {
			loginButton.className = '';
			logoutButton.className = 'hidden';
		}

		function hideLogin() {
			loginButton.className = 'hidden';
			logoutButton.className = '';
		}

		res.userName ? hideLogin() : showLogin();
	};


	 var subscribe = function(ident) {
        var selector = selectorForIdentifier( ident );
 		document.querySelector( selector + " span" ).className = 'hidden';
 		document.querySelector( selector + ' .subscribingIcon' ).className = 'subscribingIcon';

		Banner.subscribe( ident, onSubscribe );
	};

	// Perform init stuff
	Banner.loginStateChanged( onLoginChange );
	Banner.getSubscriptions( onGetSubscriptions );

	// Expose
	global.BannerDemo = {
		subscribe: subscribe
	};

})( this );